#include <iostream>
#include <cstdlib>
#include <cstdio>
#include <vector>
#include <algorithm>
using namespace std;

long long gcd(long long a, long long b)
{
    a = abs(a);
    b = abs(b);
    while (b)
    {
        a %= b;
        swap(a, b);
    }
    return a;
}

struct Ratio
{
    long long num, den;
    Ratio() : num(0), den(1) {}
    explicit Ratio(long long a) : num(a), den(1) {}
    Ratio(long long a, long long b)
    {
        if (b == 0)
            throw logic_error("Division by zero");
        long long g = gcd(a, b);
        if (b < 0)
            g = -g;
        num = a / g;
        den = b / g;
    }
    Ratio operator + (const Ratio& other) const
    {
        return Ratio(num * other.den + den * other.num, den * other.den);
    }
    Ratio operator - (const Ratio& other) const
    {
        return Ratio(num * other.den - den * other.num, den * other.den);
    }
    Ratio operator * (const Ratio& other) const
    {
        return Ratio(num * other.num, den * other.den);
    }
    Ratio operator / (const Ratio& other) const
    {
        return Ratio(num * other.den, den * other.num);
    }
    bool operator == (const Ratio& other) const
    {
        return num == other.num && den == other.den;
    }
    bool operator < (const Ratio& other) const
    {
        if ((*this) == other)
            return false;
        return ((*this) - other).num < 0;
    }
};

bool comp1(const pair<Ratio, string>& a, const pair<Ratio, string>& b)
{
    if (!(a.first == b.first))
        return a.first < b.first;
    return a.second.length() < b.second.length();
}

bool comp2(const pair<Ratio, string>& a, const pair<Ratio, string>& b)
{
    return a.first == b.first;
}

int main()
{
    string s;
    cin >> s;
    vector<vector<vector<pair<Ratio, string>>>> substr(s.length());
    for (auto& e : substr)
        e.resize(s.length() + 1);
    for (int i = 0; i < (int)s.length(); ++i)
        for (int j = 0; j <= (int)s.length(); ++j)
        {
            substr[i][j].emplace_back(0, s.substr(i, j - i));
            for (int k = i; k < j; ++k)
                substr[i][j][0].first = substr[i][j][0].first * Ratio(10) + Ratio(s[k] - '0');
        }
    for (int len = 1; len <= (int)s.length(); ++len)
        for (int i = 0; i + len <= (int)s.length(); ++i)
        {
            int j = i + len;
            for (int k = i + 1; k < j; ++k)
                for (const auto& a : substr[i][k])
                    for (const auto& b : substr[k][j])
                    {
                        substr[i][j].emplace_back(a.first + b.first, "(" + a.second + "+" + b.second + ")");
                        substr[i][j].emplace_back(a.first - b.first, "(" + a.second + "-" + b.second + ")");
                        substr[i][j].emplace_back(a.first * b.first, "(" + a.second + "*" + b.second + ")");
                        if (b.first.num != 0)
                            substr[i][j].emplace_back(a.first / b.first, "(" + a.second + "/" + b.second + ")");
                    }
            for (int i2 = 0; i2 < (int)substr[i][j].size(); ++i2)
            {
                const Ratio& cur_num = substr[i][j][i2].first;
                const string& cur_str = substr[i][j][i2].second;
                if (cur_str.length() <= 2u || (cur_str[0] != '(' || cur_str[1] != '-'))
                    substr[i][j].emplace_back(Ratio(0) - cur_num, "(-" + cur_str + ")");
            }
            sort(substr[i][j].begin(), substr[i][j].end(), comp1);
            substr[i][j].resize(unique(substr[i][j].begin(), substr[i][j].end(), comp2) - substr[i][j].begin());
        }
    for (const auto& e : substr[0][(int)s.length()])
        if (e.first == Ratio(100))
            cout << e.second << '\n';
    return 0;
}
